@@ -77,7 +77,7 @@ class Assignment(Binding):
 
 
 class FunctionDefinition(Binding):
-    pass
+    is_property = False
 
 
 
@@ -276,7 +276,9 @@ class Checker:
           reported.
         '''
         if (isinstance(self.scope.get(value.name), FunctionDefinition)
-                    and isinstance(value, FunctionDefinition)):
+                    and isinstance(value, FunctionDefinition)
+                    and not self.scope.get(value.name).is_property
+                    and not value.is_property):
             self.report(messages.RedefinedFunction,
                         lineno, value.name, self.scope[value.name].source.lineno)
 
@@ -498,9 +500,16 @@ class Checker:
             raise RuntimeError("Got impossible expression context: %r" % (node.ctx,))
 
     def FUNCTIONDEF(self, node):
+        is_property = False
         for deco in node.decorator_list:
             self.handleNode(deco, node)
-        self.addBinding(node.lineno, FunctionDefinition(node.name, node))
+            if getattr(deco, 'id', None) == 'property':
+                is_property = True
+            if getattr(deco, 'attr', None) in ('setter', 'deleter'):
+                is_property = True
+        funcdef = FunctionDefinition(node.name, node)
+        funcdef.is_property = is_property
+        self.addBinding(node.lineno, funcdef)
         self.LAMBDA(node)
 
     def LAMBDA(self, node):
@@ -522,6 +531,7 @@ class Checker:
 
             self.pushFunctionScope()
             addArgs(node.args.args)
+            addArgs(node.args.kwonlyargs)
             # vararg/kwarg identifiers are not Name nodes
             if node.args.vararg:
                 args.append(node.args.vararg)
@@ -574,7 +584,7 @@ class Checker:
 
     def AUGASSIGN(self, node):
         self.handleNodeLoad(node.target)
-        self.handleNodeLoad(node.value)
+        self.handleNode(node.value, node)
         self.handleNodeStore(node.target)
 
     def IMPORT(self, node):
@@ -608,4 +618,4 @@ class Checker:
         if node.name:
             self.handleNodeStore(node)
         self.handleChildren(node)
-        
\ No newline at end of file
+        
